You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by sa...@apache.org on 2008/01/18 11:06:48 UTC

svn commit: r613119 - in /webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2: deployment/DeploymentErrorMsgs.java deployment/POJODeployer.java i18n/resource.properties

Author: sandakith
Date: Fri Jan 18 02:06:47 2008
New Revision: 613119

URL: http://svn.apache.org/viewvc?rev=613119&view=rev
Log:
fix for the axis2 3325

Modified:
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/DeploymentErrorMsgs.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/POJODeployer.java
    webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/i18n/resource.properties

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/DeploymentErrorMsgs.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/DeploymentErrorMsgs.java?rev=613119&r1=613118&r2=613119&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/DeploymentErrorMsgs.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/DeploymentErrorMsgs.java Fri Jan 18 02:06:47 2008
@@ -67,4 +67,8 @@
     public static final String XML_STREAM_EXCEPTION = "StreamException";
     public static final String ERROR_LOADING_MESSAGE_BUILDER = "errorloadingbuilder";
     public static final String ERROR_LOADING_MESSAGE_FORMATTER = "errorloadingformatter";
+    public static final String DEPLOYING_EXCEPTION = "deployingexception";
+    public static final String STORING_FAUTY_SERVICE = "stroringfaultyservice";
+    public static final String JAXWS_JARS_MISSING = "jaxwsjarsmissing";
+    public static final String FAULTY_SERVICE_REMOVAL = "faultyserviceremoval";
 }

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/POJODeployer.java
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/POJODeployer.java?rev=613119&r1=613118&r2=613119&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/i18n/resource.properties (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/i18n/resource.properties Fri Jan 18 02:06:47 2008
@@ -275,4 +275,8 @@
 nomessagereciever=Message Receiver not found for AxisOperation: {0}
 duplicaterelatesto=The message is a duplicate (has the same reply relationship value) of an already processed message. RelatesTo = {0}
 getMessageContextError=The message context could not be retrieved due to the following error: {0}
-mismatchedModuleVersions=Tried to deploy (to {0}) a module ''{1}'' when ''{2}'' was already deployed - version mismatch!
\ No newline at end of file
+mismatchedModuleVersions=Tried to deploy (to {0}) a module ''{1}'' when ''{2}'' was already deployed - version mismatch!
+deployingexception=Deploying Exception Occured with {0}
+stroringfaultyservice=Exception occured and made the service faulty with {0}
+jaxwsjarsmissing=JAXWS jars are missing in the classpath with {0}, switching to annongen
+faultyserviceremoval=Predicting faulty service with {0}, and removing it
\ No newline at end of file



---------------------------------------------------------------------
To unsubscribe, e-mail: axis-cvs-unsubscribe@ws.apache.org
For additional commands, e-mail: axis-cvs-help@ws.apache.org
--- webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/POJODeployer.java (original)
+++ webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/deployment/POJODeployer.java Fri Jan 18 02:06:47 2008
@@ -142,6 +142,7 @@
                     zin.close();
                     fin.close();
                 } catch (Exception e) {
+                    log.debug(Messages.getMessage(DeploymentErrorMsgs.DEPLOYING_EXCEPTION,e.getMessage()),e);
                     throw new DeploymentException(e);
                 } finally {
                     if (zin != null) {
@@ -211,8 +212,10 @@
                 }
             }
         } catch (Exception e) {
+             log.debug(Messages.getMessage(DeploymentErrorMsgs.STORING_FAUTY_SERVICE,e.getMessage()),e);
             storeFaultyService(deploymentFileData, e);
         } catch (Throwable t) {
+            log.debug(Messages.getMessage(DeploymentErrorMsgs.STORING_FAUTY_SERVICE,t.getMessage()),t);
             storeFaultyService(deploymentFileData, t);
         } finally {
             if (threadClassLoader != null) {
@@ -274,8 +277,9 @@
             //setMessageReceivers(axisService);
             
         } catch (Exception e) {
-            // Seems like the jax-ws jars missin in the class path .
-            // lets tryu annogen
+            // Seems like the jax-ws jars missing in the class path .
+            // lets try with annogen
+            log.debug(Messages.getMessage(DeploymentErrorMsgs.JAXWS_JARS_MISSING,e.getMessage()),e);
             axisService = createAxisServiceUsingAnnogen(className, classLoader, serviceLocation);
         }
         return axisService;
@@ -364,6 +368,7 @@
                                              fileName));
             } catch (AxisFault axisFault) {
                 //May be a faulty service
+                log.debug(Messages.getMessage(DeploymentErrorMsgs.FAULTY_SERVICE_REMOVAL,axisFault.getMessage()),axisFault);
                 configCtx.getAxisConfiguration().removeFaultyService(fileName);
             }
         } else if (fileName.endsWith(".jar")) {
@@ -375,6 +380,7 @@
                                              fileName));
             } catch (AxisFault axisFault) {
                 //May be a faulty service
+                log.debug(Messages.getMessage(DeploymentErrorMsgs.FAULTY_SERVICE_REMOVAL,axisFault.getMessage()),axisFault);
                 configCtx.getAxisConfiguration().removeFaultyService(fileName);
             }
         }

Modified: webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/i18n/resource.properties
URL: http://svn.apache.org/viewvc/webservices/axis2/trunk/java/modules/kernel/src/org/apache/axis2/i18n/resource.properties?rev=613119&r1=613118&r2=613119&view=diff
==============================================================================